@@ -2,8 +2,6 @@
 #' @param x An 'sf' object with the same crs as the homonym parameter
 #' @keywords CRS sf Uruguay
 #' @return logical value based in crs parameter of the sf object
-#' @importFrom sf st_join st_crs
-#' @importFrom glue glue
 #' @export
 #' @examples
 #'\donttest{
@@ -12,22 +10,23 @@
 
 is.uy4326 <- function(x){
   md <- geouy::metadata 
-  if (!is(x, "sf")) stop("The object you want to process is not class sf")
+  if (!methods::is(x, "sf")) stop("The object you want to process is not class sf")
   y <- geouy::load_geouy("Uruguay", crs = 4326)
-  if (st_crs(x) != st_crs(y)) stop("The object you want to process is not at CRS 4326")
+  if (sf::st_crs(x) != sf::st_crs(y)) {
+    return("The object you want to process is not at CRS 4326")
+  } else {
   y$geometry <- NULL
   x1 <- sf::st_join(x, y, left = F)
   x2 <- (nrow(x1) / nrow(x)) * 100
   return(ifelse(x2 == 0, "Your object have not any geometry in Uruguay... Try 5381, 5382 or 32721",
                 glue::glue("Your object have {x2}% of matches with Ururguay CRS 4326")))
+  }
 }
 
 #' This function test if an 'sf' object match with Uruguay at crs = 32721.
 #' @param x An 'sf' object with the same crs as the homonym parameter
 #' @keywords CRS sf Uruguay
 #' @return logical value based in crs parameter of the sf object
-#' @importFrom sf st_join st_crs
-#' @importFrom glue glue
 #' @export
 #' @examples
 #'\donttest{
@@ -36,22 +35,23 @@ is.uy4326 <- function(x){
 
 is.uy32721 <- function(x){
   md <- geouy::metadata 
-  if (!is(x, "sf")) stop("The object you want to process is not class sf")
+  if (!methods::is(x, "sf")) stop("The object you want to process is not class sf")
   y <- geouy::load_geouy("Uruguay", crs = 32721)
-  if (st_crs(x) != st_crs(y)) stop("The object you want to process is not at CRS 32721")
-  y$geometry <- NULL
-  x1 <- sf::st_join(x, y, left = F)
-  x2 <- (nrow(x1) / nrow(x)) * 100
-  return(ifelse(x2 == 0, "Your object have not any geometry in Uruguay... Try 4326, 5381 or 5382",
-                glue::glue("Your object have {x2}% of matches with Ururguay CRS 32721")))
+  if (sf::st_crs(x) != sf::st_crs(y)){
+    return("The object you want to process is not at CRS 32721")
+  } else {
+    y$geometry <- NULL
+    x1 <- sf::st_join(x, y, left = F)
+    x2 <- (nrow(x1) / nrow(x)) * 100
+    return(ifelse(x2 == 0, "Your object have not any geometry in Uruguay... Try 4326, 5381 or 5382",
+                  glue::glue("Your object have {x2}% of matches with Ururguay CRS 32721")))
+  }
 }
 
 #' This function test if an 'sf' object match with Uruguay at crs = 5381.
 #' @param x An 'sf' object with the same crs as the homonym parameter
 #' @keywords CRS sf Uruguay
 #' @return logical value based in crs parameter of the sf object
-#' @importFrom sf st_join st_crs
-#' @importFrom glue glue
 #' @export
 #' @examples
 #'\donttest{
@@ -60,22 +60,23 @@ is.uy32721 <- function(x){
 
 is.uy5381 <- function(x){
   md <- geouy::metadata 
-  if (!is(x, "sf")) stop("The object you want to process is not class sf")
+  if (!methods::is(x, "sf")) stop("The object you want to process is not class sf")
   y <- geouy::load_geouy("Uruguay", crs = 5381)
-  if (st_crs(x) != st_crs(y)) stop("The object you want to process is not at CRS 5381")
+  if (sf::st_crs(x) != sf::st_crs(y)) {
+    return("The object you want to process is not at CRS 5381")
+  } else {
   y$geometry <- NULL
   x1 <- sf::st_join(x, y, left = F)
   x2 <- (nrow(x1) / nrow(x)) * 100
   return(ifelse(x2 == 0, "Your object have not any geometry in Uruguay... Try 4326, 5382 or 32721",
                 glue::glue("Your object have {x2}% of matches with Ururguay CRS 5381")))
+  }
 }
 
 #' This function test if an 'sf' object match with Uruguay at crs = 5382.
 #' @param x An 'sf' object with the same crs as the homonym parameter
 #' @keywords CRS sf Uruguay
 #' @return logical value based in crs parameter of the sf object
-#' @importFrom sf st_join st_crs
-#' @importFrom glue glue
 #' @export
 #' @examples
 #'\donttest{
@@ -84,12 +85,27 @@ is.uy5381 <- function(x){
 
 is.uy5382 <- function(x){
   md <- geouy::metadata 
-  if (!is(x, "sf")) stop("The object you want to process is not class sf")
+  if (!methods::is(x, "sf")) stop("The object you want to process is not class sf")
   y <- geouy::load_geouy("Uruguay", crs = 5382)
-  if (st_crs(x) != st_crs(y)) stop("The object you want to process is not at CRS 5382")
+  if (sf::st_crs(x) != sf::st_crs(y)) {
+    return("The object you want to process is not at CRS 5382")
+  } else {
   y$geometry <- NULL
   x1 <- sf::st_join(x, y, left = F)
   x2 <- (nrow(x1) / nrow(x)) * 100
   return(ifelse(x2 == 0, "Your object have not any geometry in Uruguay... Try 4326, 5381 or 32721",
                 glue::glue("Your object have {x2}% of matches with Ururguay CRS 5382")))
-}
\ No newline at end of file
+  }
+}
+
+#' Pipe operator
+#'
+#' See \code{magrittr::\link[magrittr]{\%>\%}} for details.
+#'
+#' @name %>%
+#' @rdname pipe
+#' @keywords internal
+#' @export
+#' @importFrom magrittr %>%
+#' @usage lhs \%>\% rhs
+NULL
\ No newline at end of file
